# Copyright:   (c) Daryl Fox 2013
# Licence:     CC-BY
#              http://creativecommons.org/licenses/by/3.0/
#-------------------------------------------------------------------------------

import pygame

import util

class FontError(Exception): pass

class Hud(object):
    colors = {'background': (102, 51,  0  ),
              'border':     (204, 102, 0  ),
              'text':       (255, 204, 33 ),
              'title':      (153, 0,   0  )}
    def __init__(self, size, banner, overlay):
        self.size = size
        self.followers = 0
        self.distance = 0.0

        self.banner = pygame.image.load(banner)
        self.overlay = pygame.image.load(overlay).subsurface(self.banner.get_rect())
        self._hud = pygame.Surface(size, pygame.SRCALPHA)
        self.font = util.find_font_by_height(self.size[1] * 2 / 3)

        border = 5
        width, height = self.font.size("Distance: 8888")
        mid = size[1] / 2 - height / 2
        self.followers_pos = border, mid
        self.distance_pos = size[0] - border - width, mid

    def update(self):
        followers_text = self.font.render("Followers: %2d" % self.followers,
                                          True, self.colors['text'])
        distance_text = self.font.render("Distance: %4d" % int(self.distance),
                                          True, self.colors['text'])

        self._hud.blit(self.banner, (0, 0))
        self._hud.blit(followers_text, self.followers_pos)
        self._hud.blit(distance_text, self.distance_pos)
        self._hud.blit(self.overlay, (0, 0))

    @property
    def image(self):
        return self._hud

#def find_font_by_height(target):
#    name = pygame.font.get_default_font()
#
#    size = 120
#    while size >= 6:
#        font = pygame.font.Font(name, size)
#        if font.get_height() <= target:
#            return font
#        size -= 1
#    raise FontError("Cannot find font of size %r" % target)

if __name__ == '__main__':
    pygame.init()

    def setup_window(window_size):
        winstyle = 0
        bestdepth = pygame.display.mode_ok(window_size, winstyle, 32)
        return pygame.display.set_mode(window_size, winstyle, bestdepth)


    size = 640, 40
    screen = setup_window(size)
    hud = Hud(size, 'assets/banner.png', 'assets/cloth.png')
    hud.followers = 20
    hud.distance = 995

    clock = pygame.time.Clock()
    running = True
    while running:
        dt = clock.tick(30)
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                running = False
            elif event.type == pygame.KEYDOWN:
                if event.key == pygame.K_ESCAPE:
                    running = False
                else:
                    hud.followers -= 1
        if not (dt and running):
            continue

        hud.distance += dt / 1000.0

        hud.update()
        screen.blit(hud.image, (0, 0))

        pygame.display.flip()

